@@ -30,5 +30,5 @@ p <- plotTpcaVolcano(tpca_result)
 
 expect_equal(
     class(p),
-    c("gg", "ggplot")
+    c("ggplot2::ggplot", "ggplot", "ggplot2::gg", "S7_object", "gg")
 )
